# Backlog for ds18b20-datalogger

## Iteration +1
- Better software tests
- Break out sensor mapping configuration from code
  to make it re-usable across different setups
- Improve documentation
- Publish to PyPI
